pub enum VariantReference {
ReferenceFor((VocabId, f64)),
VariantOf((VocabId, f64)),
}Variants
ReferenceFor((VocabId, f64))
The current item is a reference for a variant. The score expressed similarity from the variant to the reference.
VariantOf((VocabId, f64))
The current item is a variant of a reference item. The score expressed similarity from the variant to the reference.